@@ -19,7 +19,7 @@ type_detect_begin='
 type_detect_awk='
 	if (lname ~ "schematics?")
 		type = "schematics"
-	if (lname ~ "symbol")
+	if (lname ~ "symbols?")
 		type = "symbol"
 '
 
