@@ -16,7 +16,7 @@
  *
  *  You should have received a copy of the GNU Lesser General Public
  *  License along with this library; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ *  Foundation, Inc., 31 Milk Street, # 960789 Boston, MA 02196 USA
  *
  *  Contact:
  *    Project page: http://repo.hu/projects/sch-rnd
@@ -152,6 +152,30 @@ int csch_arc_get_endxy(const csch_arc_t *arc, int side, csch_coord_t *x, csch_co
 	return 0;
 }
 
+int csch_arc_get_midxy(const csch_arc_t *arc, csch_coord_t *x, csch_coord_t *y)
+{
+	g2d_vect_t v = g2d_carc_offs(&arc->inst.c, 0.5);
+	*x = v.x;
+	*y = v.y;
+	return 0;
+}
+
+int csch_arc_get_spec_endxy(const csch_arc_t *arc, int side, csch_coord_t *x, csch_coord_t *y)
+{
+	g2d_vect_t v = g2d_carc_offs(&arc->spec, ((side == 0) ? 0.0 : 1.0));
+	*x = v.x;
+	*y = v.y;
+	return 0;
+}
+
+int csch_arc_get_spec_midxy(const csch_arc_t *arc, csch_coord_t *x, csch_coord_t *y)
+{
+	g2d_vect_t v = g2d_carc_offs(&arc->spec, 0.5);
+	*x = v.x;
+	*y = v.y;
+	return 0;
+}
+
 
 static csch_chdr_t *arc_create(csch_sheet_t *sheet, csch_cgrp_t *parent)
 {
@@ -388,9 +412,8 @@ static int undo_arc_modify_swap(void *udata)
 
 	rnd_swap(g2d_carc_t, u->spec, u->arc->spec);
 	csch_arc_update(u->arc->hdr.sheet, u->arc, 1);
-	csch_sheet_set_changed(u->arc->hdr.sheet, 1);
 
-	csch_cobj_redraw(u->arc);
+	csch_op_geo_edited(u->arc->hdr.sheet, &u->arc->hdr);
 
 	return 0;
 }
