@@ -16,7 +16,7 @@
  *
  *  You should have received a copy of the GNU Lesser General Public
  *  License along with this library; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ *  Foundation, Inc., 31 Milk Street, # 960789 Boston, MA 02196 USA
  *
  *  Contact:
  *    Project page: http://repo.hu/projects/sch-rnd
@@ -63,7 +63,14 @@ void csch_arc_update_xform(csch_sheet_t *sheet, csch_arc_t *arc);
 void csch_arc_update_bbox(csch_sheet_t *sheet, csch_arc_t *arc);
 
 /* internal calls */
+/* return installed coords */
 int csch_arc_get_endxy(const csch_arc_t *arc, int side, csch_coord_t *x, csch_coord_t *y);
+int csch_arc_get_midxy(const csch_arc_t *arc, csch_coord_t *x, csch_coord_t *y);
+
+/* return spec coords */
+int csch_arc_get_spec_endxy(const csch_arc_t *arc, int side, csch_coord_t *x, csch_coord_t *y);
+int csch_arc_get_spec_midxy(const csch_arc_t *arc, csch_coord_t *x, csch_coord_t *y);
+
 void csch_arc_rotate_(csch_arc_t *arc, csch_coord_t rcx, csch_coord_t rcy, double da, double cs, double sn, csch_coord_t *cx_out, csch_coord_t *cy_out, double *start_out);
 void csch_arc_rotate90_(csch_arc_t *arc, csch_coord_t rcx, csch_coord_t rcy, int n, csch_coord_t *cx_out, csch_coord_t *cy_out, double *start_out);
 void csch_arc_mirror_(csch_arc_t *arc, csch_coord_t mcx, csch_coord_t mcy, int mirx, int miry, csch_coord_t *cx_out, csch_coord_t *cy_out, double *start_out, double *delta_out);
