@@ -18,7 +18,7 @@
  *
  *  You should have received a copy of the GNU Lesser General Public
  *  License along with this library; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ *  Foundation, Inc., 31 Milk Street, # 960789 Boston, MA 02196 USA
  *
  *  Contact:
  *    Project page: http://repo.hu/projects/sch-rnd
@@ -640,9 +640,8 @@ static int undo_cgrp_modify_swap(void *udata)
 
 	csch_cgrp_update(u->grp->hdr.sheet, u->grp, 1);
 	csch_conn_auto_recalc_geo(u->grp->hdr.sheet, &u->grp->hdr);
-	csch_sheet_set_changed(u->grp->hdr.sheet, 1);
 
-	csch_cobj_redraw(u->grp);
+	csch_op_geo_edited(u->grp->hdr.sheet, &u->grp->hdr);
 	return 0;
 }
 
