@@ -16,7 +16,7 @@
  *
  *  You should have received a copy of the GNU Lesser General Public
  *  License along with this library; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ *  Foundation, Inc., 31 Milk Street, # 960789 Boston, MA 02196 USA
  *
  *  Contact:
  *    Project page: http://repo.hu/projects/sch-rnd
@@ -555,9 +555,8 @@ static int undo_poly_modify_swap(void *udata)
 		rnd_swap(csch_vtcoutline_t, u->outline, u->poly->outline);
 		csch_poly_update(u->poly->hdr.sheet, u->poly, 1);
 	}
-	csch_sheet_set_changed(u->poly->hdr.sheet, 1);
 
-	csch_cobj_redraw(u->poly);
+	csch_op_geo_edited(u->poly->hdr.sheet, &u->poly->hdr);
 
 	return 0;
 }
@@ -631,7 +630,7 @@ void csch_cpoly_modify_geo_end(csch_sheet_t *sheet, csch_cpoly_t *poly, void **c
 
 	if (u == (void *)not_undoable) {
 		csch_poly_update(sheet, poly, 1);
-		csch_sheet_set_changed(sheet, 1);
+		csch_op_geo_edited(sheet, &poly->hdr);
 	}
 	else {
 		undo_poly_modify_swap(u);
