@@ -18,7 +18,7 @@
  *
  *  You should have received a copy of the GNU Lesser General Public
  *  License along with this library; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ *  Foundation, Inc., 31 Milk Street, # 960789 Boston, MA 02196 USA
  *
  *  Contact:
  *    Project page: http://repo.hu/projects/sch-rnd
@@ -576,11 +576,10 @@ static int undo_text_modify_swap(void *udata)
 	rnd_swap(int, u->dyntext, u->texto->dyntext);
 
 	csch_text_update(u->texto->hdr.sheet, u->texto, 1);
-	csch_sheet_set_changed(u->texto->hdr.sheet, 1);
 	csch_text_invalidate_font(u->texto);
 	csch_text_dyntext_inval(u->texto);
 
-	csch_cobj_redraw(u->texto);
+	csch_op_geo_edited(u->texto->hdr.sheet, &u->texto->hdr);
 
 	return 0;
 }
