@@ -18,7 +18,7 @@
  *
  *  You should have received a copy of the GNU Lesser General Public
  *  License along with this library; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ *  Foundation, Inc., 31 Milk Street, # 960789 Boston, MA 02196 USA
  *
  *  Contact:
  *    Project page: http://repo.hu/projects/sch-rnd
@@ -325,10 +325,12 @@ static int is_grp_a_sheet_port(const csch_sheet_t *sheet, csch_cgrp_t *grp)
 }
 
 /* Hierarchic: search child sheet terminals and return the abstract port that
-   has a matching port name (or NULL if not found) */
-static csch_aport_t *find_subsheet_port(csch_abstract_t *dst, csch_sheet_t *child, const char *port_name)
+   has a matching port name (or NULL if not found or error). Also sets
+   *error_indicated_out to 1 if an error message was printed. */
+static csch_aport_t *find_subsheet_port(csch_abstract_t *dst, csch_sheet_t *child, const char *port_name, int *error_indicated_out)
 {
 	csch_chdr_t *h;
+	csch_aport_t *res = NULL;
 
 	for(h = gdl_first(&child->active); h != NULL; h = gdl_next(&child->active, h)) {
 		csch_cgrp_t *grp = (csch_cgrp_t *)h;
@@ -346,15 +348,22 @@ static csch_aport_t *find_subsheet_port(csch_abstract_t *dst, csch_sheet_t *chil
 				for(n = 0; n < grp->aid.used; n++) {
 					csch_aport_t *aport = htip_get(&dst->aid2obj, grp->aid.array[n]);
 					if ((aport != NULL) && (aport->hdr.type == CSCH_ATYPE_PORT)) {
-						if (strcmp(aport->name, port_name) == 0)
-							return aport;
+						if (strcmp(aport->name, port_name) == 0) {
+							if (res != NULL) {
+								rnd_msg_error("Compilation error: sheet '%s': multiple sheet terminals are called '%s'\n", child->hidlib.loadname, port_name);
+								*error_indicated_out = 1;
+								return NULL;
+							}
+							res = aport;
+							/*go on searching for more so the above error can trigger */
+						}
 					}
 				}
 			}
 		}
 	}
 
-	return NULL;
+	return res;
 }
 
 /* Returns whether a sheet ref sym has parameter pass-down attributes */
@@ -447,12 +456,16 @@ static int compile_symbol_child_sheet(csch_abstract_t *dst, int viewid, csch_hie
 		sym_port = compile_port(dst, viewid, hpath, sheet, comp, e->value, 1);
 
 		if (sym_port != NULL) {
+			int error_indicated = 0;
+
 			sym_port_api_name = sym_port->name;
-			sym_port->subsheet_port = find_subsheet_port(dst, child, sym_port_api_name);
+			sym_port->subsheet_port = find_subsheet_port(dst, child, sym_port_api_name, &error_indicated);
+
 			if (sym_port->subsheet_port == NULL) {
-				rnd_message(RND_MSG_ERROR,
-					"Hierarchy error: sheet %s doesn't have terminal %s for symbol port %s:%s\n",
-					child->hidlib.loadname, sym_port_api_name, comp->name, sym_port_api_name);
+				if (!error_indicated)
+					rnd_message(RND_MSG_ERROR,
+						"Hierarchy error: sheet %s doesn't have terminal %s for symbol port %s:%s\n",
+						child->hidlib.loadname, sym_port_api_name, comp->name, sym_port_api_name);
 				res = -1;
 			}
 			else
