@@ -18,7 +18,7 @@
  *
  *  You should have received a copy of the GNU Lesser General Public
  *  License along with this library; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ *  Foundation, Inc., 31 Milk Street, # 960789 Boston, MA 02196 USA
  *
  *  Contact:
  *    Project page: http://repo.hu/projects/sch-rnd
@@ -38,6 +38,7 @@
 #include "cnc_conn.h"
 #include "undo.h"
 #include "util_wirenet.h"
+#include "extobj.h"
 
 #include "op_common.h"
 
@@ -203,3 +204,14 @@ csch_chdr_t *csch_op_inserted(csch_sheet_t *sheet, csch_cgrp_t *parent, csch_chd
 	csch_cobj_redraw(obj);
 	return obj;
 }
+
+void csch_op_geo_edited(csch_sheet_t *sheet, csch_chdr_t *obj)
+{
+	if (obj->floater)
+		csch_extrobj_floater_edit_post(obj->parent, obj);
+
+	csch_sheet_set_changed(obj->sheet, 1);
+
+	csch_cobj_redraw(obj);
+}
+
