@@ -16,7 +16,7 @@
  *
  *  You should have received a copy of the GNU Lesser General Public
  *  License along with this library; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ *  Foundation, Inc., 31 Milk Street, # 960789 Boston, MA 02196 USA
  *
  *  Contact:
  *    Project page: http://repo.hu/projects/sch-rnd
@@ -688,7 +688,7 @@ int csch_save_grp(csch_cgrp_t *grp, const char *fn_, const char *fmt, int inhibi
 	return ret;
 }
 
-csch_cgrp_t *csch_load_grp(csch_sheet_t *dst, const char *load_fn, const char *fmt)
+csch_cgrp_t *csch_load_grp(csch_sheet_t *dst, const char *load_fn, const char *fmt, const char *subsymname)
 {
 	vtpr_t prios;
 	int n;
@@ -732,7 +732,7 @@ csch_cgrp_t *csch_load_grp(csch_sheet_t *dst, const char *load_fn, const char *f
 			continue;
 
 		rewind(f);
-		res = pr->io->load_grp(f, real_fn, fmt, dst);
+		res = pr->io->load_grp(f, real_fn, fmt, subsymname, dst);
 	}
 	vtpr_uninit(&prios);
 	free(real_fn);
