@@ -18,7 +18,7 @@
  *
  *  You should have received a copy of the GNU Lesser General Public
  *  License along with this library; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ *  Foundation, Inc., 31 Milk Street, # 960789 Boston, MA 02196 USA
  *
  *  Contact:
  *    Project page: http://repo.hu/projects/sch-rnd
@@ -59,7 +59,7 @@ typedef struct csch_plug_io_s {
 	int (*save_buffer)(const char *fn, const char *fmt, const csch_sheet_t *dst);
 
 	/* useful for saving/loading symbols */
-	csch_cgrp_t *(*load_grp)(FILE *f, const char *fn, const char *fmt, csch_sheet_t *sheet);
+	csch_cgrp_t *(*load_grp)(FILE *f, const char *fn, const char *fmt, const char *subsymname, csch_sheet_t *sheet);
 	int (*save_grp)(const char *fn, const char *fmt, const csch_cgrp_t *src, int inhibit_uuid);
 
 	int (*export_prio)(const char *fn, const char *fmt, csch_plug_io_type_t type);
@@ -103,7 +103,7 @@ void csch_plug_io_unregister(const csch_plug_io_t *io);
 csch_sheet_t *csch_load_sheet(csch_project_t *proj, const char *fn, const char *fmt, int *already_in_proj, FILE *optf);
 
 csch_project_t *csch_load_project(const char *fn, const char *fmt, int with_sheets);
-csch_cgrp_t *csch_load_grp(csch_sheet_t *dst, const char *load_fn, const char *fmt);
+csch_cgrp_t *csch_load_grp(csch_sheet_t *dst, const char *load_fn, const char *fmt, const char *subsymname);
 
 int csch_save_sheet(csch_sheet_t *sheet, const char *fn, const char *fmt);
 int csch_save_sheet_backup(csch_sheet_t *sheet, const char *fn, const char *fmt); /* does not make the sheet look saved */
