@@ -2,7 +2,7 @@
  *                            COPYRIGHT
  *
  *  cschem - modular/flexible schematics editor - libcschem (core library)
- *  Copyright (C) 2022 Tibor 'Igor2' Palinkas
+ *  Copyright (C) 2022,2025 Tibor 'Igor2' Palinkas
  *  Copyright (C) 1994,1995,1996 Thomas Nau (from pcb-rnd)
  *
  *  This library is free software; you can redistribute it and/or
@@ -17,7 +17,7 @@
  *
  *  You should have received a copy of the GNU Lesser General Public
  *  License along with this library; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ *  Foundation, Inc., 31 Milk Street, # 960789 Boston, MA 02196 USA
  *
  *  Contact:
  *    Project page: http://repo.hu/projects/sch-rnd
@@ -33,6 +33,7 @@
 #include <librnd/hid/tool.h>
 #include <librnd/core/compat_misc.h>
 #include "event.h"
+#include "cnc_obj.h"
 
 #include "undo.h"
 
@@ -63,7 +64,9 @@ int csch_undo(csch_sheet_t *sheet)
 		return -1;
 	}
 
+	csch_cobj_redraw_freeze(sheet);
 	res = uundo_undo(&sheet->undo);
+	csch_cobj_redraw_unfreeze(sheet);
 
 	if (res != 0)
 		rnd_message(RND_MSG_ERROR, "ERROR: Failed to undo some operations\n");
@@ -100,7 +103,9 @@ int csch_redo(csch_sheet_t *sheet)
 		return 0;
 	}
 
+	csch_cobj_redraw_freeze(sheet);
 	res = uundo_redo(&sheet->undo);
+	csch_cobj_redraw_unfreeze(sheet);
 
 	if (res != 0)
 		rnd_message(RND_MSG_ERROR, "ERROR: Failed to redo some operations\n");
