@@ -11,3 +11,7 @@ int csch_lht_parse_attribs(csch_attribs_t *dst, lht_node_t *subtree, void (*erro
 
 /* Build a lihata subtree for a view; return NULL on error */
 lht_node_t *csch_view2lht(const csch_view_t *view);
+
+/* Same as csch_view2lht, but takes view_node, an existing ha:viewname and 
+   replaces its children node with the new conversion */
+lht_node_t *csch_view2lht_in(lht_node_t *view_node, const csch_view_t *view);
