@@ -18,7 +18,7 @@
  *
  *  You should have received a copy of the GNU Lesser General Public
  *  License along with this library; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ *  Foundation, Inc., 31 Milk Street, # 960789 Boston, MA 02196 USA
  *
  *  Contact:
  *    Project page: http://repo.hu/projects/sch-rnd
@@ -548,9 +548,14 @@ static void csch_wirenet_recalc_merges(csch_sheet_t *sheet, csch_cgrp_t *grp)
 		/* figure number of names and new name, if needed */
 		for(n = 0; n < adj_grp.used; n++) {
 			csch_cgrp_t *agrp = adj_grp.array[n];
-			const char *name = csch_attrib_get_str(&agrp->attr, "name");
+			const char *name;
+
+			if (agrp == NULL)
+				continue;
+			name = csch_attrib_get_str(&agrp->attr, "name");
 			if (name == NULL)
 				continue;
+
 			if (final_name == NULL)
 				new_name = final_name = name;
 			num_names++;
@@ -561,6 +566,8 @@ static void csch_wirenet_recalc_merges(csch_sheet_t *sheet, csch_cgrp_t *grp)
 		grp->role = 0; /* disable side effects during the merge */
 		for(n = 0; n < adj_grp.used; n++) {
 			csch_cgrp_t *agrp = adj_grp.array[n];
+			if (agrp == NULL)
+				continue;
 			rnd_trace("  #%ld\n", agrp->hdr.oid);
 			agrp->role = 0;
 			csch_op_merge_into_remember(sheet, grp, agrp, &newos);
@@ -1026,7 +1033,7 @@ static void csch_wirenet_newseg2wirenets(csch_sheet_t *sheet, crmap_t *map, csch
 		if (!csch_obj_is_junction(&line->hdr)) { /* real wire lines should not get removed */
 			assert(!csch_obj_is_deleted(&line->hdr));
 		}
-		if (seg != my_seg) {
+		if ((seg != my_seg) && (seg >= 0)) {
 			wn = (csch_cgrp_t **)vtp0_get(new_wirenets, seg, 0);
 			if ((wn == NULL) || (*wn == NULL)) {
 				wn_ = csch_wirenet_new_from(sheet, line->hdr.parent);
@@ -1105,6 +1112,14 @@ void csch_wirenet_recalc_line_chg(csch_sheet_t *sheet, csch_line_t *line)
 	if ((line_wn == NULL) || (line_wn->role != CSCH_ROLE_WIRE_NET))
 		return;
 
+	if ((line->spec.p1.x == line->spec.p2.x) && (line->spec.p1.y == line->spec.p2.y)) {
+		/* avoid a whole lot of corner cases by simply removing a wire line the user resized to 0 length */
+/*		rnd_trace("zero length line removed\n");*/
+		csch_op_remove(sheet, &line->hdr);
+		csch_wirenet_recalc_junctions(sheet, line_wn);
+		return;
+	}
+
 	if (sheet->util_wirenet.recalc_inhibit) {
 		htpi_set(&sheet->util_wirenet.recalc_wn, line_wn, 1);
 		return;
