@@ -55,6 +55,10 @@ int csch_is_wireline_safe(csch_sheet_t *sheet, csch_coord_t x1, csch_coord_t y1,
    wirenet is empty */
 void csch_wirenet_post_remove_checks(csch_sheet_t *sheet, csch_cgrp_t *wn, int undoable);
 
+/* Return the wire that's at x;y; if ignore_line is not NULL, ignore that
+   object (useful if there are multiple lines on the same spot) */
+csch_line_t *csch_find_wire_at(csch_sheet_t *sheet, csch_coord_t x, csch_coord_t y, csch_chdr_t *ignore_line);
+
 
 /*** low level ***/
 
