@@ -18,7 +18,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ *  Foundation, Inc., 31 Milk Street, # 960789 Boston, MA 02196 USA.
  *
  *  Contact:
  *    Project page: http://repo.hu/projects/sch-rnd
@@ -40,6 +40,9 @@ static int sch_rnd_breakup_grp(csch_sheet_t *sheet, csch_cgrp_t *dst, csch_cgrp_
 	long res = 0;
 	htip_entry_t *e;
 
+	if (src->role == CSCH_ROLE_WIRE_NET)
+		rnd_message(RND_MSG_WARNING, "A wirenet group got broken up; this resulted in wire-looking lines that do not act as wires.\nThis is probably not what you wanted to do, you may want to consder an undo.\n");
+
 	for(e = htip_first(&src->id2obj); e != NULL; e = htip_next(&src->id2obj, e)) {
 		csch_chdr_t *newo = csch_op_copy_into(sheet, dst, e->value);
 		if (newo != NULL)
