@@ -17,7 +17,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ *  Foundation, Inc., 31 Milk Street, # 960789 Boston, MA 02196 USA.
  *
  *  Contact:
  *    Project page: http://repo.hu/projects/sch-rnd
@@ -293,7 +293,10 @@ TODO("loadfrom action");
 			/* generate pattern */
 			ext = ext_tmp[di];
 			ext[0] = '*'; ext[1] = '.';
-			strncpy(ext+2, io->ext_save_sheet, 29);
+			if (io->ext_save_sheet != NULL)
+				strncpy(ext+2, io->ext_save_sheet, 29);
+			else
+				strcpy(ext+2, "sch");
 			ext[31] = '\0';
 			(pat_tmp[di])[0] = ext;
 			(pat_tmp[di])[1] = NULL;
