@@ -16,7 +16,7 @@
 
     You should have received a copy of the GNU Library General Public
     License along with this library; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+    Foundation, Inc., 31 Milk Street, # 960789 Boston, MA 02196 USA.
 */
 
 /* These functions parse "EasyEDA pro" file formats; these semi-json files
