@@ -19,7 +19,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ *  Foundation, Inc., 31 Milk Street, # 960789 Boston, MA 02196 USA.
  *
  *  Contact:
  *    Project page: http://repo.hu/projects/sch-rnd
@@ -905,7 +905,7 @@ TODO
 }
 
 /* IO API function (load symbol from lib) */
-csch_cgrp_t *io_eeschema_load_grp(FILE *f, const char *fn, const char *fmt, csch_sheet_t *sheet)
+csch_cgrp_t *io_eeschema_load_grp(FILE *f, const char *fn, const char *fmt, const char *subsymname, csch_sheet_t *sheet)
 {
 	read_ctx_t ctx = {0};
 	csch_cgrp_t *grp;
