@@ -18,7 +18,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ *  Foundation, Inc., 31 Milk Street, # 960789 Boston, MA 02196 USA.
  *
  *  Contact:
  *    Project page: http://repo.hu/projects/sch-rnd
@@ -862,8 +862,7 @@ static void uninit_sym_hash(read_ctx_t *ctx)
 		disk_sym_t *ds = htent->value;
 		free(ds->name);
 		free(ds->path);
-		if (ds->grp != NULL)
-			csch_cgrp_free(ds->grp);
+		/* no need to: csch_cgrp_free(ds->grp); - all groups were in the scratch buffer and that buffer is cleared */
 		free(ds);
 	});
 }
@@ -1335,7 +1334,7 @@ static csch_cgrp_t *load_sym(rnd_design_t *hidlib, const char *fn, csch_sheet_t
 }
 
 /* IO API function (load symbol from lib) */
-csch_cgrp_t *io_geda_load_grp(FILE *f, const char *fn, const char *fmt, csch_sheet_t *sheet)
+csch_cgrp_t *io_geda_load_grp(FILE *f, const char *fn, const char *fmt, const char *subsymname, csch_sheet_t *sheet)
 {
 	read_ctx_t ctx = {0};
 	csch_cgrp_t *grp;
