@@ -19,7 +19,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ *  Foundation, Inc., 31 Milk Street, # 960789 Boston, MA 02196 USA.
  *
  *  Contact:
  *    Project page: http://repo.hu/projects/sch-rnd
@@ -365,6 +365,7 @@ static int parse_oidpath(read_ctx_t *ctx, char **dst, const lht_node_t *src)
 	return 0;
 }
 
+/* defaults to 0 if src is NULL */
 static int parse_double(read_ctx_t *ctx, double *dst, const lht_node_t *src)
 {
 	char *end;
@@ -388,6 +389,7 @@ static int parse_double(read_ctx_t *ctx, double *dst, const lht_node_t *src)
 	return 0;
 }
 
+/* does not overwrite dst if src is NULL */
 static int parse_double_maybe(read_ctx_t *ctx, double *dst, const lht_node_t *src)
 {
 	if (src == NULL) return 0;
@@ -1201,7 +1203,7 @@ int io_lihata_load_project(FILE *f, const char *fn, const char *fmt, csch_projec
 	return res;
 }
 
-csch_cgrp_t *io_lihata_load_grp(FILE *f, const char *fn, const char *fmt, csch_sheet_t *sheet)
+csch_cgrp_t *io_lihata_load_grp(FILE *f, const char *fn, const char *fmt, const char *subsymname, csch_sheet_t *sheet)
 {
 	csch_cgrp_t *resgrp = NULL;
 	char *errmsg = NULL;
