@@ -16,7 +16,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ *  Foundation, Inc., 31 Milk Street, # 960789 Boston, MA 02196 USA.
  *
  *  Contact:
  *    Project page: http://repo.hu/projects/sch-rnd
@@ -32,6 +32,6 @@
 int io_lihata_load_sheet(FILE *f, const char *fn, const char *fmt, csch_sheet_t *dst);
 int io_lihata_load_buffer(FILE *f, const char *fn, const char *fmt, csch_sheet_t *dst);
 int io_lihata_load_project(FILE *f, const char *fn, const char *fmt, csch_project_t *dst, int with_sheets);
-csch_cgrp_t *io_lihata_load_grp(FILE *f, const char *fn, const char *fmt, csch_sheet_t *sheet);
+csch_cgrp_t *io_lihata_load_grp(FILE *f, const char *fn, const char *fmt, const char *subsymname, csch_sheet_t *sheet);
 int io_lihata_test_parse(FILE *f, const char *fn, const char *fmt, csch_plug_io_type_t type);
 
