@@ -10,6 +10,9 @@ typedef struct {
 			RND_CFT_BOOLEAN emulate_text_ang_180;  /* TODO: ? orcad displays text objects with angle==180 with an extra 180 degree rotation; it's a display hack sch-rnd doesn't have; when this emulation is enabled, the loader adds a +180 degree rotation in such text (changing data!) to match the behavior */
 			RND_CFT_BOOLEAN auto_normalize;        /* move all objects so that starting coords are near 0;0 */
 			RND_CFT_LIST postproc_sheet_load;      /* pattern;action pairs for object transformations after a succesful load; mostly used for attribute editing */
+			const struct {
+				RND_CFT_BOOLEAN trace_test_parse;
+			} debug;
 		} io_orcad;
 	} plugins;
 } conf_io_orcad_t;
