@@ -15,6 +15,8 @@ int main(int argc, char* argv[])
 
 	for(i=1;i<argc;++i)
 	{
+		struct orcad_node* node;
+
 		io_orcad_rctx_t rctx;
 		memset(&rctx, 0, sizeof(rctx));
 		rctx.fn = argv[i];
@@ -28,12 +30,11 @@ int main(int argc, char* argv[])
 			continue;
 		}
 
-/*
 		if(NULL!=(node=orcad_read_cache(&rctx)))
 		{
 			orcad_dump(node);
+			orcad_free(node);
 		}
-*/
 
 		fio_fclose(&rctx);
 	}
