@@ -18,7 +18,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ *  Foundation, Inc., 31 Milk Street, # 960789 Boston, MA 02196 USA.
  *
  *  Contact:
  *    Project page: http://repo.hu/projects/sch-rnd
@@ -287,6 +287,7 @@ static int sch_rnd_edit_text_dialog_dynamic(csch_sheet_t *sheet, csch_text_t *te
 		RND_DAD_COMPFLAG(ctx.dlg, RND_HATF_EXPFILL);
 
 		RND_DAD_BEGIN_HBOX(ctx.dlg);
+			RND_DAD_COMPFLAG(ctx.dlg, RND_HATF_EXPFILL);
 			RND_DAD_BEGIN_VBOX(ctx.dlg);
 				RND_DAD_LABEL(ctx.dlg, spaces);
 				RND_DAD_LABEL(ctx.dlg, "First subst val:");
@@ -294,6 +295,7 @@ static int sch_rnd_edit_text_dialog_dynamic(csch_sheet_t *sheet, csch_text_t *te
 			RND_DAD_END(ctx.dlg);
 
 			RND_DAD_STRING(ctx.dlg);
+				RND_DAD_COMPFLAG(ctx.dlg, RND_HATF_EXPFILL);
 				RND_DAD_HELP(ctx.dlg, help_subst1);
 				ctx.wattr1 = RND_DAD_CURRENT(ctx.dlg);
 				RND_DAD_CHANGE_CB(ctx.dlg, dyntext_attr1_cb);
@@ -310,6 +312,7 @@ static int sch_rnd_edit_text_dialog_dynamic(csch_sheet_t *sheet, csch_text_t *te
 
 
 		RND_DAD_BEGIN_HBOX(ctx.dlg);
+			RND_DAD_COMPFLAG(ctx.dlg, RND_HATF_EXPFILL);
 			RND_DAD_BEGIN_VBOX(ctx.dlg);
 				RND_DAD_LABEL(ctx.dlg, spaces);
 				RND_DAD_LABEL(ctx.dlg, "First subst key:");
@@ -318,6 +321,7 @@ static int sch_rnd_edit_text_dialog_dynamic(csch_sheet_t *sheet, csch_text_t *te
 			RND_DAD_END(ctx.dlg);
 
 			RND_DAD_STRING(ctx.dlg);
+				RND_DAD_COMPFLAG(ctx.dlg, RND_HATF_EXPFILL);
 				RND_DAD_HELP(ctx.dlg, help_subst1);
 				ctx.wsubst1 = RND_DAD_CURRENT(ctx.dlg);
 				RND_DAD_CHANGE_CB(ctx.dlg, dyntext_subst1_cb);
@@ -333,6 +337,7 @@ static int sch_rnd_edit_text_dialog_dynamic(csch_sheet_t *sheet, csch_text_t *te
 		RND_DAD_END(ctx.dlg);
 
 		RND_DAD_BEGIN_HBOX(ctx.dlg);
+			RND_DAD_COMPFLAG(ctx.dlg, RND_HATF_EXPFILL);
 			RND_DAD_BEGIN_VBOX(ctx.dlg);
 				RND_DAD_LABEL(ctx.dlg, spaces);
 				RND_DAD_LABEL(ctx.dlg, "Raw (template):");
@@ -340,6 +345,7 @@ static int sch_rnd_edit_text_dialog_dynamic(csch_sheet_t *sheet, csch_text_t *te
 				RND_DAD_LABEL(ctx.dlg, spaces);
 			RND_DAD_END(ctx.dlg);
 			RND_DAD_STRING(ctx.dlg);
+				RND_DAD_COMPFLAG(ctx.dlg, RND_HATF_EXPFILL);
 				RND_DAD_WIDTH_CHR(ctx.dlg, 32);
 				RND_DAD_HELP(ctx.dlg, help_raw);
 				ctx.wtext = RND_DAD_CURRENT(ctx.dlg);
