@@ -18,7 +18,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ *  Foundation, Inc., 31 Milk Street, # 960789 Boston, MA 02196 USA.
  *
  *  Contact:
  *    Project page: http://repo.hu/projects/sch-rnd
@@ -125,7 +125,7 @@ static int symlib_fs_load(csch_sheet_t *sheet, void *dst_, csch_lib_t *src, cons
 
 			rv = run_parametric(&sheet->hidlib, src->realpath, params, tmp);
 			if (rv == 0) {
-				grp = csch_load_grp(dst, tmp, NULL);
+				grp = csch_load_grp(dst, tmp, NULL, NULL);
 				if (grp != NULL) {
 					/* do not let the system remember the temp file name, put back the real file name */
 					free(grp->file_name);
@@ -138,7 +138,7 @@ static int symlib_fs_load(csch_sheet_t *sheet, void *dst_, csch_lib_t *src, cons
 		}
 		break;
 		case CSCH_SLIB_STATIC:
-			grp = csch_load_grp(dst, src->realpath, NULL);
+			grp = csch_load_grp(dst, src->realpath, NULL, NULL);
 			break;
 
 		case CSCH_SLIB_invalid:
