@@ -18,7 +18,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ *  Foundation, Inc., 31 Milk Street, # 960789 Boston, MA 02196 USA.
  *
  *  Contact:
  *    Project page: http://repo.hu/projects/sch-rnd
@@ -255,16 +255,10 @@ void sch_rnd_buffer_paste(csch_sheet_t *sheet, csch_sheet_t *buffer, csch_coord_
 
 int sch_rnd_buffer_clear(csch_sheet_t *buffer)
 {
-	csch_chdr_t *obj, *next;
-
 	uundo_freeze_add(&buffer->undo);
-	for(obj = gdl_first(&buffer->active); obj != NULL; obj = next) {
-		next = gdl_next(&buffer->active, obj);
-		if ((obj != &buffer->direct.hdr) && (obj != &buffer->indirect.hdr))
-			csch_cobj_uninit(obj);
-	}
+	csch_cgrp_clear(&buffer->direct);
+	csch_cgrp_clear(&buffer->indirect);
 	uundo_unfreeze_add(&buffer->undo);
-
 	return 0;
 }
 
@@ -374,15 +368,30 @@ fgw_error_t csch_act_BufferSave(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 			{
 				csch_cgrp_t *grp = NULL, *dir = &(SCH_RND_PASTEBUFFER->direct);
 				htip_entry_t *e;
+				int has_grp = 0, empty = 1;
 
 				for(e = htip_first(&dir->id2obj); e != NULL; e = htip_next(&dir->id2obj, e)) {
 					csch_cgrp_t *o = e->value;
-					if ((o->hdr.type == CSCH_CTYPE_GRP) && (anygrp || (o->role == CSCH_ROLE_SYMBOL))) {
-						grp = o;
-						break;
+					empty= 0;
+					if (o->hdr.type == CSCH_CTYPE_GRP) {
+						if (anygrp || (o->role == CSCH_ROLE_SYMBOL)) {
+							grp = o;
+							break;
+						}
+						has_grp = 1;
 					}
 				}
-				if (grp != NULL)
+				if (grp == NULL) {
+					if (empty)
+						rnd_message(RND_MSG_ERROR, "Empty buffer - nothing to save\n");
+					else if ((cmd == F_Symbol) && has_grp)
+						rnd_message(RND_MSG_ERROR, "The buffer does have at least one group object in it, but no symbols\n");
+					else if (!has_grp)
+						rnd_message(RND_MSG_ERROR, "The buffer has no group objects in it\n");
+					else
+						rnd_message(RND_MSG_ERROR, "The buffer has no suitable objects in it\n");
+				}
+				else
 					rv = csch_save_grp(grp, fn, fmt, 1);
 			}
 			break;
@@ -398,17 +407,18 @@ fgw_error_t csch_act_BufferSave(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	return 0;
 }
 
-static const char csch_acts_BufferLoad[] = "BufferLoad([group|symbol|all, [filename], [fmt])";
-static const char csch_acth_BufferLoad[] = "Load content of buffer from file\n";
+static const char csch_acts_BufferLoad[] = "BufferLoad([group|symbol|all, [filename], [fmt], [subsymname])";
+static const char csch_acth_BufferLoad[] = "Load content of buffer from file; when loading a symbol from a file containing multiple symbols, subsymname can be used to select which one is loaded\n";
 fgw_error_t csch_act_BufferLoad(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 {
 	int rv = -1, cmd = F_Sheet;
 	char *fn = NULL;
-	const char *fmt = NULL;
+	const char *fmt = NULL, *subsymname = NULL;
 
 	RND_ACT_MAY_CONVARG(1, FGW_KEYWORD, BufferLoad, cmd = fgw_keyword(&argv[1]));
 	RND_ACT_MAY_CONVARG(2, FGW_STR, BufferLoad, fn = argv[2].val.str);
 	RND_ACT_MAY_CONVARG(3, FGW_STR, BufferLoad, fmt = argv[3].val.str);
+	RND_ACT_MAY_CONVARG(4, FGW_STR, BufferLoad, subsymname = argv[4].val.str);
 
 	if (fn == NULL) {
 		static char *default_file = NULL;
@@ -429,7 +439,7 @@ fgw_error_t csch_act_BufferLoad(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	switch(cmd) {
 		case F_Symbol:
 		case F_Group:
-			if (csch_load_grp(SCH_RND_PASTEBUFFER, fn, fmt) != NULL)
+			if (csch_load_grp(SCH_RND_PASTEBUFFER, fn, fmt, subsymname) != NULL)
 				rv = 0;
 			break;
 		case F_All:
