@@ -16,7 +16,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ *  Foundation, Inc., 31 Milk Street, # 960789 Boston, MA 02196 USA.
  *
  *  Contact:
  *    Project page: http://repo.hu/projects/sch-rnd
@@ -69,6 +69,11 @@ static char *dotdir = NULL;
 
 void sch_rnd_conf_core_postproc(void)
 {
+	/* Note: this function is also called directly from sch_rnd_sheet_new(),
+	   running on empty config (when loading alien format sheet from the GUI),
+	   so it should not expect existing configuration for either read or write;
+	   it should alter only read-only thigns like conf_core.rc.path */
+
 	rnd_conf_force_set_str(conf_core.rc.path.prefix, SCH_PREFIX);   rnd_conf_ro("rc/path/prefix");
 	rnd_conf_force_set_str(conf_core.rc.path.lib, SCHLIBDIR);       rnd_conf_ro("rc/path/lib");
 	rnd_conf_force_set_str(conf_core.rc.path.bin, BINDIR);          rnd_conf_ro("rc/path/bin");
