@@ -22,6 +22,9 @@ void sch_rnd_redraw(rnd_design_t *target);
 void sch_rnd_expose_main(rnd_hid_t *hid, const rnd_hid_expose_ctx_t *region, rnd_xform_t *xform_caller);
 void sch_rnd_expose_preview(rnd_hid_t *hid, rnd_hid_expose_ctx_t *e);
 
+/* save of the last viewbox rendered */
+extern rnd_box_t sch_rnd_last_main_expose_region;
+
 
 /*** calls useful in preview ***/
 void sch_rnd_draw_sheet(csch_sheet_t *sheet, rnd_hid_gc_t gc, const rnd_hid_expose_ctx_t *region, rnd_xform_t *xform_caller);
