@@ -15,7 +15,10 @@ csch_project_t *sch_rnd_multi_load_project(const char *load_fn, const char *proj
 
 csch_sheet_t *sch_rnd_multi_load(const char *fn, const char *fmt, int *is_project);
 csch_sheet_t *sch_rnd_multi_new_empty(const char *fn);
-csch_sheet_t *sch_rnd_multi_new_empty_in_prj(csch_project_t *prj);
+csch_sheet_t *sch_rnd_multi_new_empty_in_prj(csch_project_t *prj, const char *path);
+
+/* App-side loader for external hierarchic child sheets from hlibrary */
+csch_sheet_t *sch_rnd_app_load_sheet(csch_project_t *proj, const char *path);
 
 /* Assuming s is not the current sheet, unload it, removing from the list of
    sheets. If s is NULL, unload currently active sheet. */
