@@ -1,6 +1,7 @@
 void sch_rnd_prj_postproc(csch_project_t *prj);
 
-/* Asks the user and creates the project file for sheet. Returns 0
+/* Checks the project file for the given sheet. If it exists, returns 0.
+   Else asks the user and creates the project file for sheet; returns 0
    if created, -1 if not (cancel or error; errors are reported in
    the message log) */
 int sch_rnd_project_create_file_for_sheet_gui(csch_sheet_t *sheet);
@@ -25,9 +26,6 @@ void sch_rnd_project_views_save(csch_sheet_t *sheet);
    doc of the currently active config tree */
 int sch_rnd_project_view_lib2lht(csch_view_t *view);
 
-/* Write out the project file */
-void sch_rnd_project_flush(void);
-
 /* Remove sheet from its current project; remove project if it became empty.
    Return number of sheet removals (should be 0 or 1 normally). */
 int sch_rnd_prj_remove_sheet(csch_sheet_t *sheet);
