@@ -18,7 +18,7 @@ csch_chdr_t *sch_rnd_search_obj_at_unsel(csch_sheet_t *sheet, csch_coord_t x, cs
 
 /* Return the preferred visible object at x;y for inspection (e.g. right click
    popup) or NULL if nothing found */
-csch_chdr_t *sch_rnd_search_first_gui_inspect(csch_sheet_t *sheet, csch_coord_t x, csch_coord_t y);
+csch_chdr_t *sch_rnd_search_first_gui_inspect(csch_sheet_t *sheet, rnd_coord_t x, rnd_coord_t y);
 
 
 /* Append all visible objects that has a bbox intersecting with box to res */
