@@ -15,4 +15,9 @@ void sch_rnd_unselect_all(csch_sheet_t *sheet);
 
 void sch_rnd_select_invert(csch_sheet_t *sheet);
 
+/* Compute bbox of selected objects on sheet; returns number of selected
+   objects considered (0 means no selection, negative means error). Fills
+   dst in with screen (rnd_coord_t) coordinates */
+long sch_rnd_get_selection_bbox_gui(rnd_box_t *dst, csch_sheet_t *sheet);
+
 #endif
