@@ -6,3 +6,6 @@ rnd_coord_t sch_rnd_sheet_attr_crd(csch_sheet_t *sheet, const char *key, rnd_coo
 
 /* Throw an error when sheet gets too large (only once per sheet) */
 void sch_rnd_sheet_warn_size(csch_sheet_t *sheet, csch_coord_t x1, csch_coord_t y1, csch_coord_t x2, csch_coord_t y2);
+
+/* Recalc from scratch - time consuming but accurate */
+void sch_rnd_sheet_recalc_bbox(csch_sheet_t *sheet);
