@@ -21,6 +21,11 @@ do
 		rm "$out"
 	else
 		bad=1
+		echo "" >&2
+		echo "--- Begin execution log for $bn:" >&2
+		cat $log >&2
+		echo "--- End execution log" >&2
+		echo "" >&2
 	fi
 done
 
