@@ -27,6 +27,8 @@ done
 if test $bad = 0
 then
 	echo "*** QC PASS ***"
+	true
 else
 	echo "Failed raw spice tests: $bad of $all"
+	false
 fi
